# `goedwig` changelog

## 0.1.4

2021-10-10

  * reworked versioning to store Git tags in a Py module


## 0.1.3

2021-10-10

  * reworked versioning to store Git tags in a file


## 0.1.2

2021-10-10

  * fix versioning bug


## 0.1.1

2021-10-10

  * Python packaging


## 0.1.0

2021-10-10

  * initial commit
